@@ -53,16 +53,41 @@
         }
 
         function onMouseDown(ev) {
+            if (
+                '%(drag_region_direct_target_only)s' === 'True' &&
+                !ev.target.matches('%(drag_selector)s')
+            ) {
+                return
+            }
+
             initialX = ev.clientX;
             initialY = ev.clientY;
             window.addEventListener('mouseup', onMouseUp);
             window.addEventListener('mousemove', onMouseMove);
         }
 
-        var dragBlocks = document.querySelectorAll('%(drag_selector)s');
-        for (var i=0; i < dragBlocks.length; i++) {
-            dragBlocks[i].addEventListener('mousedown', onMouseDown);
+        function onBodyMouseDown(event) {
+            var target = event.target;
+            var dragSelectorElements = document.querySelectorAll('%(drag_selector)s');
+
+            while (target && target !== document.body && target !== document.documentElement) {
+                if (target.nodeType === 1) {
+                    // Check if target matches the drag selector
+                    for (var i = 0; i < dragSelectorElements.length; i++) {
+                        if (dragSelectorElements[i] === target) {
+                            onMouseDown(event);
+                            return;
+                        }
+                    }
+                }
+
+                // If it doesn't match, continue up the DOM tree
+                target = target.parentNode;
+            }
         }
+
+        document.body.addEventListener('mousedown', onBodyMouseDown);
+
             // easy drag for edge chromium
         if ('%(easy_drag)s' === 'True') {
             window.addEventListener('mousedown', onMouseDown);
@@ -86,16 +111,13 @@
 
         // draggable
         if ('%(draggable)s' === 'False') {
-            Array.prototype.slice.call(document.querySelectorAll("img")).forEach(function(img) {
-                img.setAttribute("draggable", false);
-            })
-
-            Array.prototype.slice.call(document.querySelectorAll("a")).forEach(function(a) {
-                a.setAttribute("draggable", false);
-            })
+            document.addEventListener('dragstart', function(e) {
+                if (e.target.tagName === 'IMG' || e.target.tagName === 'A') {
+                    e.preventDefault();
+                }
+            });
         }
     }
 
     disableTouchEvents();
   })();
-
