@@ -1,10 +1,13 @@
 from __future__ import annotations
 
 from collections.abc import Callable
+from typing import Any, Union
 
 
 class Menu:
-    def __init__(self, title: str, items: list[str] = []) -> None:
+    def __init__(
+        self, title: str, items: list[Union[Menu, MenuAction, MenuSeparator]] = []
+    ) -> None:
         """
         Args:
             title: the menu or submenu title
@@ -15,7 +18,7 @@ class Menu:
 
 
 class MenuAction:
-    def __init__(self, title: str, function: Callable[[], None]) -> None:
+    def __init__(self, title: str, function: Callable[[], Any]) -> None:
         self.title = title
         self.function = function
         # TODO: support platform-agnostic shortcut
